"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("mz/fs");
const p_limit_1 = require("p-limit");
const path = require("path");
const limit = p_limit_1.default(20);
const MAX_BULK_SIZE = 1 * 1024 * 1024; // 1MB
async function default_1(cafs, dirname) {
    const index = {};
    await _retrieveFileIntegrities(cafs, dirname, dirname, index);
    return index;
}
exports.default = default_1;
async function _retrieveFileIntegrities(cafs, rootDir, currDir, index) {
    try {
        const files = await fs.readdir(currDir);
        await Promise.all(files.map(async (file) => {
            const fullPath = path.join(currDir, file);
            const stat = await fs.stat(fullPath);
            if (stat.isDirectory()) {
                await _retrieveFileIntegrities(cafs, rootDir, fullPath, index);
                return;
            }
            if (stat.isFile()) {
                const relativePath = path.relative(rootDir, fullPath);
                index[relativePath] = {
                    generatingIntegrity: limit(() => {
                        return stat.size < MAX_BULK_SIZE
                            ? fs.readFile(fullPath).then((buffer) => cafs.addBuffer(buffer, stat.mode))
                            : cafs.addStream(fs.createReadStream(fullPath), stat.mode);
                    }),
                    mode: stat.mode,
                    size: stat.size,
                };
            }
        }));
    }
    catch (err) {
        if (err.code !== 'ENOENT') {
            throw err;
        }
    }
}
//# sourceMappingURL=addFilesFromDir.js.map