"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const rimraf = require("@zkochan/rimraf");
const fs = require("mz/fs");
const p_limit_1 = require("p-limit");
const ssri = require("ssri");
const _1 = require(".");
const limit = p_limit_1.default(20);
const MAX_BULK_SIZE = 1 * 1024 * 1024; // 1MB
async function default_1(cafsDir, integrityObj) {
    let verified = true;
    await Promise.all(Object.keys(integrityObj)
        .map((f) => limit(async () => {
        const fstat = integrityObj[f];
        if (!fstat.integrity) {
            throw new Error(`Integrity checksum is missing for ${f}`);
        }
        if (!await verifyFile(_1.getFilePathInCafs(cafsDir, fstat), fstat)) {
            verified = false;
        }
    })));
    return verified;
}
exports.default = default_1;
async function verifyFile(filename, fstat) {
    if (fstat.size > MAX_BULK_SIZE) {
        try {
            const ok = Boolean(await ssri.checkStream(fs.createReadStream(filename), fstat.integrity));
            if (!ok) {
                await rimraf(filename);
            }
            return ok;
        }
        catch (err) {
            switch (err.code) {
                case 'ENOENT': return false;
                case 'EINTEGRITY': {
                    // Broken files are removed from the store
                    await rimraf(filename);
                    return false;
                }
            }
            throw err;
        }
    }
    try {
        const data = await fs.readFile(filename);
        const ok = Boolean(ssri.checkData(data, fstat.integrity));
        if (!ok) {
            await rimraf(filename);
        }
        return ok;
    }
    catch (err) {
        switch (err.code) {
            case 'ENOENT': return false;
            case 'EINTEGRITY': {
                // Broken files are removed from the store
                await rimraf(filename);
                return false;
            }
        }
        throw err;
    }
}
//# sourceMappingURL=checkFilesIntegrity.js.map