"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const get_context_1 = require("@pnpm/get-context");
const lockfile_utils_1 = require("@pnpm/lockfile-utils");
const logger_1 = require("@pnpm/logger");
const dp = require("dependency-path");
const dint = require("dint");
const loadJsonFile = require("load-json-file");
const pFilter = require("p-filter");
const path = require("path");
const extendStoreStatusOptions_1 = require("./extendStoreStatusOptions");
async function default_1(maybeOpts) {
    const reporter = maybeOpts === null || maybeOpts === void 0 ? void 0 : maybeOpts.reporter;
    if (reporter) {
        logger_1.streamParser.on('data', reporter);
    }
    const opts = await extendStoreStatusOptions_1.default(maybeOpts);
    const { registries, storeDir, skipped, virtualStoreDir, wantedLockfile, } = await get_context_1.getContextForSingleImporter({}, {
        ...opts,
        extraBinPaths: [],
    });
    if (!wantedLockfile)
        return [];
    const pkgs = Object.keys(wantedLockfile.packages || {})
        .filter((relDepPath) => !skipped.has(relDepPath))
        .map((relDepPath) => {
        return {
            pkgPath: dp.resolve(registries, relDepPath),
            ...lockfile_utils_1.nameVerFromPkgSnapshot(relDepPath, wantedLockfile.packages[relDepPath]),
        };
    });
    const modified = await pFilter(pkgs, async ({ pkgPath, name }) => {
        const integrity = await loadJsonFile(path.join(storeDir, pkgPath, 'integrity.json'));
        return (await dint.check(path.join(virtualStoreDir, pkgPath, 'node_modules', name), integrity)) === false;
    });
    if (reporter) {
        logger_1.streamParser.removeListener('data', reporter);
    }
    return modified.map(({ pkgPath }) => pkgPath);
}
exports.default = default_1;
//# sourceMappingURL=index.js.map